sheets_store library

Classes

SheetColumn<T extends Object?>
A table to store data in represented as a column in sheets
SheetInteractionHandler
Provides low level functions for reading and writing to a sheet. It's best recommended not to use this unless all other methods of using a sheet is not fit for your use.
SheetMap<K extends Object, V extends Object>
A map of keys and values. Very similar to the javascript Map
SheetsClient
SheetTable<K extends Object?, V extends Object?>
Treats a whole sheet as a giant map where each column is a key and each row is a map of values. This can result in more human-readable sheets instead of the sheet acting just as a bare bones database.

Functions

base10Convert(int value, String baseDigits) String